# CLArena (Continual Learning Arena)

**An open-source machine learning package for continual learning research**

This is a open-source Python package for Continual Learning (CL) research, solely developed by myself. In this package, I provide a integrated environment and various APIs to conduct CL experiments for research purposes, as well as implemented CL algorithms and datasets that you can give it a spin immediately.

Please find out more information and complete documentation hosted in my blog:

<https://pengxiang-wang.com/projects/continual-learning-arena/>
